Crate etopay_wallet

Crate etopay_wallet 

Re-exports

pub use bip39;

Modules

types

Structs

MnemonicDerivationOption
Options that can be given to customize the mnemonic derivation
TransactionIntent
The intended transaction to perform. Used to perform the transaction and estimate gas fees.
WalletImplEvm
WalletUser implementation for EVM
WalletImplEvmErc20
WalletUser implementation for EVM-ERC20
WalletImplIotaRebased

Enums

WalletError
Wrapper for wallet errors

Traits

WalletUser
Wallet user interface

Type Aliases

Result
A core::result::Result with WalletError as its error variant.